## Webrunner
> Project Kanban \
> https://github.com/users/JE-Chen/projects/35 \
> Multiton Selenium Instance testing \
> The WEB Testing component is a web automation testing solution based on Selenium. \
> It wraps Selenium and therefore has all the functionality of Selenium. \
> What problems does it solve? 
>> * Automatically downloads and updates the required web driver, so users no longer need to install it manually.
>> * Provides the ability to simultaneously run and monitor multiple Selenium instances.
>> * Provides a keyword-based testing approach that Selenium does not have.
>> * Can produce test reports that record actions taken during the test.
>> * Can execute tests remotely through TCP/IP.
>> * Offers a CLI mode for Web Testing.
---

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/cc97412a6f3e4c5592ce45dd7b9db946)](https://www.codacy.com/gh/JE-Chen/WebRunner/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/WebRunner&amp;utm_campaign=Badge_Grade)

[![CircleCI](https://dl.circleci.com/status-badge/img/gh/Integrated-Testing-Environment/WebRunner/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/Integrated-Testing-Environment/WebRunner/tree/main)

[![WebRunner GitHub Actions Dev](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_dev.yml/badge.svg)](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_dev.yml)

[![WebRunner GitHub Actions Stable](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_stable.yml/badge.svg)](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_stable.yml)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/webrunner-dev/badge/?version=latest)](https://webrunner-dev.readthedocs.io/en/latest/?badge=latest)

---

## install

```
pip install je_web_runner
```

## Requires

```
python 3.7 or later
```

>* Test on
>>    * Windows 10 ~ 11
>>    * osx 10.5 ~ 11 big sur
>>    * ubuntu 20.0.4
>>    * raspberry pi 3B+

| All test in test dir